==> igniteui-react-charts-16.6.8.tgz: package/ES2015/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new RateOfChangeAndMomentumIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return RateOfChangeAndMomentumIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qq() {
        return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.qr));
    }
    set qq(a) {
        this.h(RateOfChangeAndMomentumIndicator.qr, a);
    }
    qb() {
        return this.qq;
    }
    qk(a) {
        this.qq = a;
    }
}
RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
RateOfChangeAndMomentumIndicator.qr = StrategyBasedIndicator.qn(14, RateOfChangeAndMomentumIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new RateOfChangeAndMomentumIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return RateOfChangeAndMomentumIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qx() {
        return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.qy));
    }
    set qx(a) {
        this.h(RateOfChangeAndMomentumIndicator.qy, a);
    }
    qi() {
        return this.qx;
    }
    qr(a) {
        this.qx = a;
    }
}
RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
RateOfChangeAndMomentumIndicator.qy = StrategyBasedIndicator.qu(14, RateOfChangeAndMomentumIndicator.$);
